

NAME = "pophacks"
VERSION = "1.0.0"

DESCRIPTION = "A collection of fun hacks on popular culture"

AUTHOR = "Shreyas Ranganatha"
AUTHOR_EMAIL = "shreyass.ranganatha@gmail.com"

MAINTAINER = "Shreyas Ranganatha"
MAINTAINER_EMAIL = "shreyass.ranganatha@gmail.com"

if __name__ == "__main__":
    print("{} `{}`".format(NAME, VERSION))
